@@ -90,6 +90,10 @@ class CommonBrowserView(BrowserView):
             return False
         else:
             return True
+        
+    def checkPermission(self, item, permission):
+        secman = getSecurityManager()
+        return secman.checkPermission(permission, item)
     
     def slideshow(self, parent):
         """
